use serenity::{prelude::GatewayIntents, Client};

use crate::environment::get_env_variable;

use super::event_handler::Handler;

const INTENTS: GatewayIntents = GatewayIntents::empty();

struct DiscordClient {
    serenity_client: Option<Client>,

    discord_token: String,
}

impl DiscordClient {
    pub async fn new() -> Self {
        let discord_token = get_env_variable("DISCORD_TOKEN");

        let serenity_client = match Client::builder(&discord_token, INTENTS)
            .event_handler(Handler)
            .await
        {
            Ok(c) => c,
            Err(e) => panic!("Failed to instantiate Discord Client: {e}"),
        };

        DiscordClient {
            discord_token,
            serenity_client: Some(serenity_client),
        }
    }
}
